==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/SaveGenericQuery.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

-- [dbo].[SaveGenericQuery] 'inconcert', ''
CREATE PROCEDURE [dbo].[SaveGenericQuery] (
	@VCC							VARCHAR(50) = NULL,
	@Name							VARCHAR(50) = NULL,
	@Description					VARCHAR(100) NULL,
	@Query							VARCHAR(MAX) = NULL,
	@RawData						VARCHAR(MAX) = NULL,
	@CreatedDate					DATETIME = NULL,
	@CreatedByUserId				VARCHAR(50) = NULL, 	
	@LastModifiedDate				DATETIME = NULL,
	@LastModifiedByUserId			VARCHAR(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	UPDATE [GenericQuery] SET
		[Name] = @Name,
		[Description] = @Description,
		[Query] = @Query,
		[RawData] = @RawData,
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE()
	WHERE
		[VCC] = @VCC
		AND [Name] = @Name

    IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [GenericQuery]
		(
			[VCC],
			[Name],
			[Description],
			[Query],
			[RawData],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId],
			[TimeStamp]
		)
		VALUES
		(
			@VCC,
			@Name,
			@Description,
			@Query,
			@RawData,
			@CreatedDate,
			@CreatedByUserId,
			@LastModifiedDate, 
			@LastModifiedByUserId,
			GETUTCDATE()
		)
	END

    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/SaveGenericQuery.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

-- [dbo].[SaveGenericQuery] 'inconcert', ''
CREATE PROCEDURE [dbo].[SaveGenericQuery] (
	@VCC							VARCHAR(50) = NULL,
	@Name							VARCHAR(50) = NULL,
	@Description					VARCHAR(100) NULL,
	@Query							VARCHAR(MAX) = NULL,
	@RawData						VARCHAR(MAX) = NULL,
	@CreatedDate					DATETIME = NULL,
	@CreatedByUserId				VARCHAR(50) = NULL, 	
	@LastModifiedDate				DATETIME = NULL,
	@LastModifiedByUserId			VARCHAR(50) = NULL,
	@Version                        SMALLINT = 1
	)
AS
BEGIN
	SET NOCOUNT ON

	UPDATE [GenericQuery] SET
		[Name] = @Name,
		[Description] = @Description,
		[Query] = @Query,
		[RawData] = @RawData,
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE()
	WHERE
		[VCC] = @VCC
		AND [Name] = @Name

    IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [GenericQuery]
		(
			[VCC],
			[Name],
			[Description],
			[Query],
			[RawData],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId],
			[Version],
			[TimeStamp]
		)
		VALUES
		(
			@VCC,
			@Name,
			@Description,
			@Query,
			@RawData,
			@CreatedDate,
			@CreatedByUserId,
			@LastModifiedDate, 
			@LastModifiedByUserId,
			@Version,
			GETUTCDATE()
		)
	END

    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
